@@ -597,6 +597,8 @@ class TestShipping(unittest.TestCase):
                         start_state: {
                             'carrier': self.carrier,
                             'shipment': sale.shipments[0],
+                            'override_weight':
+                                sale.shipments[0].override_weight,
                         },
                     }
 
@@ -611,21 +613,13 @@ class TestShipping(unittest.TestCase):
                 session_id, start_state, end_state = self.LabelWizard.create()
                 result = self.LabelWizard.execute(session_id, {}, start_state)
                 self.assertEqual(result.keys(), ['view'])
-                self.assertEqual(result['view']['buttons'], [
-                    {
-                        'default': False,
-                        'states': '{}',
-                        'state': 'next',
-                        'string': 'Continue',
-                        'icon': 'tryton-go-next'
-                    }
-                ])
                 self.assertEqual(len(self.Attachment.search([])), 0)
 
                 data = {
                     start_state: {
                         'carrier': self.carrier,
                         'shipment': sale.shipments[0],
+                        'override_weight': sale.shipments[0].override_weight,
                     },
                 }
 
